# Python Connector for Oracle #

Python Connector for Oracle is a connectivity solution for accessing Oracle
databases from Python applications. It fully implements the Python DB API 2.0
specification. The connector is distributed as a wheel package for Windows,
macOS, and Linux.
 
Direct connection
 
The connector enables you to establish a direct connection to Oracle from
a Python application via TCP/IP, eliminating the need for the database
client libraries. A direct connection increases the speed of data
transmission between the application and Oracle database server and
streamlines the deployment process since you don't have to distribute any
client libraries with the application.
 
Secure communication
 
The connector supports encrypted communications using SSL/TLS, SSH
tunneling, and HTTP/HTTPS tunneling.

## Using the connector ##

To retrieve data from a database:
 
Import the module.
 
```
import devart.oracle
```
 
Connect to a database using the `connect()` module method and obtain a `connection` object.
 
```
my_connection = devart.oracle.connect(
    Direct=True,
    Host="your_server",
    ServiceName="your_service_name",
    UserName="your_username",
    Password="your_password"
)
```
 
Create a `cursor` object using the `cursor()` connection method.
 
```
my_cursor = my_connection.cursor()
```
 
Execute the SQL statement using the `execute()` cursor method.
 
```
my_cursor.execute("SELECT * FROM employees")
```
 
Retrieve the result set using one of the `fetch*()` cursor methods.
 
```
for row in my_cursor.fetchall(): 
    print(row)
```

## What's new ##

Python Connector for Oracle 1.0
 
* Initial release of Python Connector for Oracle
* Added support for Windows 32-bit and 64-bit
* Added support for Windows Server 32-bit and 64-bit
* Added support for macOS 64-bit and ARM (Apple M1 and M2)
* Added support for Linux 64-bit
